<?php
namespace Service;

use \Util\Exception;
use \SimpleXMLElement;

class Payment {

	protected $entityManager;
	protected $waiterMessage;
	protected $util;
	protected $tableService;
	protected $impressaoUtil;
	protected $impressaoPedido;
	protected $databaseUtil;
	protected $impressaoPedidoSmart;
	protected $instanceManager;
	protected $cartaoTodo;
	protected $fidelidadeOnline;

	public function __construct(
		\Doctrine\ORM\EntityManager $entityManager,
		\Util\WaiterMessage $waiterMessage, \Util\Util $util, 
		\Service\Table $tableService, 
		\Odhen\API\Lib\ImpressaoUtil $impressaoUtil, 
		\Odhen\API\Service\ImpressaoPedido $impressaoPedido, 
		\Odhen\API\Util\Database $databaseUtil, 
		\Odhen\API\Service\ImpressaoPedidoSmart $impressaoPedidoSmart, 
		\Zeedhi\Framework\DependencyInjection\InstanceManager $instanceManager,
		\Odhen\API\Service\CartaoTodo $cartaoTodo,
		\Odhen\API\Service\FidelidadeOnline $fidelidadeOnline
		){
		$this->entityManager = $entityManager;
		$this->waiterMessage = $waiterMessage;
		$this->util = $util;
		$this->tableService = $tableService;
 		$this->impressaoUtil = $impressaoUtil;
		$this->impressaoPedido = $impressaoPedido;
		$this->databaseUtil = $databaseUtil;
		$this->impressaoPedidoSmart = $impressaoPedidoSmart;
		$this->instanceManager  = $instanceManager;
		$this->cartaoTodo  = $cartaoTodo;
		$this->fidelidadeOnline  = $fidelidadeOnline;
	}

	public function getMoneyCurrency($CDFILIAL, $NRCONFTELA, $DTINIVIGENCIA) {
		$params = array(
			'CDFILIAL' => $CDFILIAL,
			'NRCONFTELA' => $NRCONFTELA,
            'DTINIVIGENCIA' => new \DateTime($DTINIVIGENCIA)
		);
        $types = array(
            'DTINIVIGENCIA' => \Doctrine\DBAL\Types\Type::DATETIME
        );
		return $this->entityManager->getConnection()->fetchAssoc("SQL_GET_MONEY_CURRENCY", $params, $types);
	}

    public function getChangeType($CDTIPORECE){
        $params = array(
            'CDTIPORECE' => $CDTIPORECE
        );
        $changeType = $this->entityManager->getConnection()->fetchAssoc("GET_CHANGE_TYPE", $params);
        if (empty($changeType)) $result = null;
        else $result = $changeType['CDTIPOTROCO'];

        return $result;
    }

	public function getOcorTxts($ocorrGroup, $ocorrIds) {
		$params = array(
			'CDGRPOCOR' => $ocorrGroup,
			'CDOCORR' => $ocorrIds
		);

		$types = array(
			'CDGRPOCOR' => \PDO::PARAM_STR,
			'CDOCORR' => \Doctrine\DBAL\Connection::PARAM_STR_ARRAY
		);

		$values = $this->entityManager->getConnection()->fetchAll("SQL_GET_OCORR_TEXTS", $params, $types);

		return array_map(function($obs) {
			return $obs['DSOCORR'];
		}, $values);
	}

	public function initiatesAnticipate($chave, $DATASALE, $TIPORECE, $CDCLIENTE, $CDCONSUMIDOR, $NRMESA, $NRVENDAREST, $NRCOMANDA, $NRINSCRCONS, $arrayPosicoes){
		$result = Array(
			'error' => true,
			'message' => ''
		);
		$connection = false;

		try {
			$this->entityManager->getConnection()->beginTransaction();
			$connection = true;
		} catch (\Exception $e) {
			Exception::logException($e);
			$result['message'] = $this->waiterMessage->getMessage('265');
		}

		if ($connection) {
			try {
				$position = 'T'; // padrão adiantamento como mesa
				$session  = $this->util->getSessionVars($chave);
				$dateTime = new \DateTime('NOW', new \DateTimeZone('America/Bahia'));
				$NMCONSVEND = null;

				// pega CDCLIENTE e CDCONSUMIDOR para posição específica. caso não houver, CDCLIENTE/CDCONSUMIDOR da mesa se mantém
				if (!empty($arrayPosicoes)){
					$posvendarest = $this->tableService->getPosition($session, $NRVENDAREST, $arrayPosicoes);
					if (!empty($posvendarest)) {
						$CDCLIENTE 	  = $posvendarest[0]['CDCLIENTE'];
						$CDCONSUMIDOR = $posvendarest[0]['CDCONSUMIDOR'];
						$NMCONSVEND   = $posvendarest[0]['DSCONSUMIDOR'];
					}
					$position = $arrayPosicoes[0];
				}

				if (!empty($NRINSCRCONS) || !empty($NMCONSVEND)){
					// atualiza CPF/CNPJ na ITCOMANDAVEN para o adiantamento
					$params = array(
						'NRINSCRCONS' => $NRINSCRCONS,
						'NMCONSVEND' => $NMCONSVEND,
						'CDFILIAL' => $session['CDFILIAL'],
						'NRVENDAREST' => $NRVENDAREST,
						'NRCOMANDA' => $NRCOMANDA,
						'NRLUGARMESA' => $arrayPosicoes,
						'ALL' => $position
					);
					$type = array(
						'NRLUGARMESA' => \Doctrine\DBAL\Connection::PARAM_STR_ARRAY,
						'ALL' => \PDO::PARAM_STR
					);
					$this->entityManager->getConnection()->executeQuery("SQL_UPDATE_ITCOMANDAVEN_ADIANTAMENTO", $params, $type);
				}

				$params = Array(
					'CDFILIAL' 		 => $session['CDFILIAL'],
					'CDCAIXA' 		 => $session['CDCAIXA'],
					'CDVENDEDOR' 	 => $session['CDVENDEDOR'],
					'NRLUGARMESA' 	 => $position,
					'NRVENDAREST'    => $NRVENDAREST,
					'NRCOMANDA'      => $NRCOMANDA,
					'NRMESA'   		 => $NRMESA,
					'NRSEQVENDA' 	 => null, // atualizado após registro ir para a MOVCAIXA
					'CDCLIENTE'		 => $CDCLIENTE,
					'CDCONSUMIDOR'	 => $CDCONSUMIDOR,
					'DTHRINCMOV' 	 => $dateTime,
					'IDTIPMOV' 		 => 'E', // 'E' = entrada
					// para transações com sucesso
					'IDADMTASK' 	 => '0',
					'IDSTMOV'	     => '1',
					//
					'IDATIVO' 		 => 'S',
					'NRORG' 		 => $session['NRORG'],
					'NRORGINCLUSAO'  => $session['NRORG'],
					'CDOPERINCLUSAO' => $session['CDOPERADOR'],
					'DTINCLUSAO'	 => $dateTime,
					'IDADIANTAMENTO' => 'S'
				);
				$types = array(
					'DTHRINCMOV' => \Doctrine\DBAL\TypeS\Type::DATETIME,
					'DTINCLUSAO' => \Doctrine\DBAL\TypeS\Type::DATETIME
				);
				foreach ($TIPORECE as $recebimento) {
					// um NRSEQMOVMOB por recebimento
					$this->util->newCode('MOVCAIXAMOB' . $session['CDFILIAL']);
					$params['NRSEQMOVMOB']  = $this->util->getNewCode('MOVCAIXAMOB' . $session['CDFILIAL'], 10);
					$params['CDTIPORECE'] 	= $recebimento['CDTIPORECE'];
					$params['VRMOV'] 	    = $recebimento['VRMOVIVEND'];
					$params['IDTPTEF'] 		= $recebimento['IDTPTEF'];
					$params['NRADMCODE'] 	= $recebimento['NRCONTROLTEF'];
					$params['CDNSUTEFMOB']  = !empty($recebimento['CDNSUHOSTTEF']) ? $recebimento['CDNSUHOSTTEF'] : null;
					$params['DSBANDEIRA'] 	= $recebimento['CDBANCARTCR'];
					$params['TXPRIMVIATEF'] = !empty($recebimento['STLPRIVIA']) ? $recebimento['STLPRIVIA'] : null;
					$params['TXSEGVIATEF']  = !empty($recebimento['STLSEGVIA']) ? $recebimento['STLSEGVIA'] : null;
					$params['NRCARTBANCO']  = empty($recebimento['NRCARTBANCO']) ? null : $recebimento['NRCARTBANCO'];
					$params['IDTIPORECE']   = $recebimento['IDTIPORECE'];
					$params['TRANSACTIONCODE']  = !empty($recebimento['TRANSACTIONCODE']) ? $recebimento['TRANSACTIONCODE'] : null;
					$params['TRANSACTIONID']  = !empty($recebimento['TRANSACTIONID']) ? $recebimento['TRANSACTIONID'] : null;
					$params['CDNSUTEFINTMOB'] = !empty($recebimento['CDNSUTEF']) ? $recebimento['CDNSUTEF'] : $params['CDNSUTEFMOB'];
					$params['NRAUTORIZATEF'] = !empty($recebimento['NRAUTORIZATEF']) ? $recebimento['NRAUTORIZATEF'] : null;
					$params['IDSTATUSMOV'] = null;

					$this->entityManager->getConnection()->executeQuery("SQL_INSERT_MOVCAIXAMOB", $params, $types);
				}

				$this->entityManager->getConnection()->commit();
				$result['error'] = false;
			} catch (\Exception $e) {
				Exception::logException($e);
				$this->entityManager->getConnection()->rollBack();
				$result['message'] = $e->getMessage();
			}
		}

		return $result;
	}

	public function printTEFVoucher($arrTiporece, $CDFILIAL, $CDCAIXA, $NRORG){
		$result = array(
			'error' => true,
			'message' => '',
			'data' => array(),
			'paramsImpressora' => array()
		);

		try {
			$params = array(
				'CDFILIAL' => $CDFILIAL,
				'CDCAIXA' => $CDCAIXA,
				'NRORG' => $NRORG
			);
			$dadosImpressora = $this->entityManager->getConnection()->fetchAssoc("SQL_BUSCA_DADOS_IMPRESSORA", $params);

			if (!empty($dadosImpressora)){
				$printerParams = $this->impressaoUtil->buscaParametrosImpressora($dadosImpressora['IDMODEIMPRES']);

				$arrTEFVoucher = array_map(function($recebimento) use ($printerParams){
					// tratamento específico para os comprovantes do TEF da Cappta
					$STLPRIVIA = array_key_exists("STLPRIVIA", $recebimento) ? $recebimento['STLPRIVIA'] : null;
					$STLSEGVIA = array_key_exists("STLSEGVIA", $recebimento) ? $recebimento['STLSEGVIA'] : null;

					if($printerParams['impressaoFront']) {
						$STLPRIVIA = str_replace("\n", $printerParams['comandoEnter'], $STLPRIVIA);
						$STLSEGVIA = str_replace("\n", $printerParams['comandoEnter'], $STLSEGVIA);
					}

					return array(
						'STLPRIVIA' => $STLPRIVIA,
						'STLSEGVIA' => $STLSEGVIA
					);
				}, $arrTiporece);

				if (!$printerParams['impressaoFront']){
					$tefVoucherResult = array(
						'error' => false
					);
					foreach ($arrTEFVoucher as $tefVoucher) {
						$tefVoucherResult = $this->impressaoUtil->imprimeNaoFiscal($tefVoucher['STLPRIVIA'], $dadosImpressora);
						if(isset($tefVoucherResult['saas'])&&$tefVoucherResult['saas']){
							array_push($result['paramsImpressora'], $tefVoucherResult['paramsImpressora']);
						}
						if (!$tefVoucherResult['error'] && $tefVoucher['STLSEGVIA'] !== ''){
							$tefVoucherResult = $this->impressaoUtil->imprimeNaoFiscal($tefVoucher['STLSEGVIA'], $dadosImpressora);
							if(isset($tefVoucherResult['saas'])&&$tefVoucherResult['saas']){
								array_push($result['paramsImpressora'], $tefVoucherResult['paramsImpressora']);
							}
						}

						if ($tefVoucherResult['error']){
							break;
						}
					}

					if ($tefVoucherResult['error']){
						$message = !empty($tefVoucherResult['exceptionMessage']) ?
							$dadosImpressora['NMIMPRLOJA'] . ': ' . $tefVoucherResult['exceptionMessage'] : $tefVoucherResult['message'];
						$result['message'] = 'Ocorreu um problema na impressão do comprovante TEF.<br><br>' . $message;
					} else {
						$result['error'] = false;
					}
				} else {
					$result['error'] = false;
					$result['data'] = $arrTEFVoucher;
				}
			} else {
				$result['message'] = 'Impressora não parametrizada para o caixa.';
	        }
		} catch(\Exception $e) {
			Exception::logException($e);
			$result['message'] = $e->getMessage();
		}

	    return $result;
	}

	public function findNRCPFRESPCON($CDCLIENTE, $CDCONSUMIDOR, $NRORG){
		$params = array(
			'CDCLIENTE' => $CDCLIENTE,
			'CDCONSUMIDOR' => $CDCONSUMIDOR,
			'NRORG' => $NRORG
		);

		$result = $this->entityManager->getConnection()->fetchAssoc("SQL_GET_NRCPFRESPCON", $params);
		return !empty($result['NRCPFRESPCON']) ? $result['NRCPFRESPCON'] : null;
	}

	public function findNMCONSUMIDOR($CDCLIENTE, $CDCONSUMIDOR, $NRORG){
		$params = array(
			'CDCLIENTE' => $CDCLIENTE,
			'CDCONSUMIDOR' => $CDCONSUMIDOR,
			'NRORG' => $NRORG
		);

		$result = $this->entityManager->getConnection()->fetchAssoc("SQL_GET_NMCONSUMIDOR", $params);
		return $result['NMCONSUMIDOR'];
	}

	public function checkSaleCode($CDFILIAL, $NRVENDAREST, $NRCOMANDA, $CDORDERWAITER) {
		self::changeTableParams($NRVENDAREST, $NRCOMANDA);

		$params = array(
			'CDFILIAL' => $CDFILIAL,
			'NRVENDAREST' => $NRVENDAREST,
			'NRCOMANDA' => $NRCOMANDA,
			'CDORDERWAITER' => $CDORDERWAITER
		);

		return $this->entityManager->getConnection()->fetchAssoc("SQL_CHECK_ORDERCODE", $params);
	}

	public function insertSaleCode($IDSTORDER, $DSOPERACAO, $CDFILIAL, $NRVENDAREST, $NRCOMANDA, $CDORDERWAITER) {
		self::changeTableParams($NRVENDAREST, $NRCOMANDA);

		$params = array(
			'IDSTORDER' => $IDSTORDER,
			'DSOPERACAO' => $DSOPERACAO,
			'CDFILIAL' => $CDFILIAL,
			'NRVENDAREST' => $NRVENDAREST,
			'NRCOMANDA' => $NRCOMANDA,
			'CDORDERWAITER' => $CDORDERWAITER,
			'DTHRINCREQ' => new \DateTime()
		);

        $type = array();
        if (!$this->databaseUtil->databaseIsOracle()){
            $type['DSOPERACAO'] = \Doctrine\DBAL\Types\Type::BINARY;
        }
        $type['DTHRINCREQ'] = \Doctrine\DBAL\Types\Type::DATETIME;

		$this->entityManager->getConnection()->executeQuery("SQL_INSERE_WAITER_ORDERS", $params, $type);
	}

	public function updateSaleCode($IDSTORDER, $DSOPERACAO, $CDFILIAL, $NRVENDAREST, $NRCOMANDA, $CDORDERWAITER) {
		self::changeTableParams($NRVENDAREST, $NRCOMANDA);

		$params = array(
			'IDSTORDER' => $IDSTORDER,
			'DSOPERACAO' => $DSOPERACAO,
			'CDFILIAL' => $CDFILIAL,
			'NRVENDAREST' => $NRVENDAREST,
			'NRCOMANDA' => $NRCOMANDA,
			'CDORDERWAITER' => $CDORDERWAITER
		);
        $type = array();
        if (!$this->databaseUtil->databaseIsOracle()){
            $type['DSOPERACAO'] = \Doctrine\DBAL\Types\Type::BINARY;
        }
		$this->entityManager->getConnection()->executeQuery("SQL_UPDATE_WAITER_ORDERS", $params, $type);
	}

	private function changeTableParams(&$NRVENDAREST, &$NRCOMANDA){
		// modifica para 'X' NRVENDAREST e NRCOMANDA quando é modo balcão
		$NRVENDAREST = !empty($NRVENDAREST) ? $NRVENDAREST : 'X';
		$NRCOMANDA = !empty($NRCOMANDA) ? $NRCOMANDA : 'X';
	}

	public function printOrderCupom($CDFILIAL, $CDLOJA, $ITEMVENDA, $CDVENDEDOR, $CDSENHAPED, $NRSEQVENDA, $CDCAIXA, $IDIMPPEDPRCIGE, $NRNOTAFISCALCE, $NRORG){
		try {
			// adiciona produtos filhos a serem impressos
			$arrProduct = array();
			foreach ($ITEMVENDA as $product) {
				array_push($arrProduct, $product);
				$product['itensCombo']=isset($product['itensCombo'])?$product['itensCombo']:array();
				foreach ($product['itensCombo'] as $itemCombo) {
					$itemCombo['IDIMPPRGRPROMO'] = 'N';
					array_push($arrProduct, $itemCombo);
					$itemCombo['itensCombo']=isset($itemCombo['itensCombo'])?$itemCombo['itensCombo']:array();
					foreach ($itemCombo['itensCombo'] as $comboDentro) {
						//impressao combo dentro de combo
                        $comboDentro['IDIMPPRGRPROMO'] = 'N';
                        array_push($arrProduct, $comboDentro);
					}
				}
			}

			$result = $this->impressaoPedido->imprimePedido(
				$CDFILIAL,
				$CDLOJA,
				$arrProduct,
				$CDVENDEDOR,
				null,
				null,
				$CDSENHAPED,
				'B',
				'',
				false,
				true,
				$NRSEQVENDA,
				$CDCAIXA,
				$IDIMPPEDPRCIGE
			);

			$result['PedidoSmart'] = $this->impressaoPedidoSmart->imprimePedidoSmart(
				$CDFILIAL,
				$CDLOJA,
				$arrProduct,
				$CDVENDEDOR,
				null,
				null,
				$CDSENHAPED,
				'B',
				'',
				false,
				true,
				$CDCAIXA,
				$NRNOTAFISCALCE,
				$NRORG
			);

		} catch (\Exception $e) {
			Exception::logException($e);
			$result = array(
				'error' => true,
				'message' => $e->getMessage()
			);
		}

		return $result;
	}

    public function getProduct($CDPRODUTO){
        $params = array($CDPRODUTO);
        return $this->entityManager->getConnection()->fetchAssoc("SQL_GET_PRODUTO", $params);
    }

    public function buscaVendaRealizada($CDFILIAL, $NRVENDAREST, $NRCOMANDA){
        $params = array(
            'CDFILIAL' => $CDFILIAL,
            'NRVENDAREST' => $NRVENDAREST,
            'NRCOMANDA' => $NRCOMANDA,
        );
        return $this->entityManager->getConnection()->fetchAssoc("BUSCA_VENDA_REALIZADA", $params);
    }

    public function logServDesc ($logServico, $logDesconto, $NRMESA, $NRCOMANDA, $CDFILIAL, $CDCAIXA, $CDOPERADOR, $supervisorServ, $supervisorDesc, $NRSEQVENDA) {
    	if ($logServico != null) {
        	$idOperFos = $logServico;
        	if ($logServico == 'ADD_TAX') {
        		$dsMotivoFos = 'Waiter - Adiciona taxa de serviço.';
        		$dsLivreFos = 'Adiciona taxa de serviço da Mesa/Comanda: ' . $NRMESA . '/' . $NRCOMANDA . '_';
        	} else if ($logServico == 'RET_TAX'){
        		$dsMotivoFos = 'Waiter - Retira taxa de serviço.';
        		$dsLivreFos = 'Retira taxa de serviço da Mesa/Comanda: ' . $NRMESA . '/' . $NRCOMANDA . '_';
        	} else{
        		$dsMotivoFos = 'Waiter - Alterar valor da Taxa de Serviço.';
        		$dsLivreFos = 'Alterar valor da Taxa de Serviço da Mesa/Comanda: ' . $NRMESA . '/' . $NRCOMANDA . '_';
        	}
        	$this->util->logFOS($CDFILIAL, $CDCAIXA, $idOperFos, $CDOPERADOR, $supervisorServ, $dsMotivoFos, $dsLivreFos);
        }

        if ($logDesconto != null) {
        	$this->util->logFOS($CDFILIAL, $CDCAIXA, 'CUP_DES', $CDOPERADOR, $supervisorDesc, 'Waiter - Cupom com desconto.', 'Desconto no cupom nº ' . $NRSEQVENDA);
        }
    }

    public function getPaymentDelivery($cdfilial, $nrvendarest, $nrcomanda){

    	$params = array(
    		'CDFILIAL' 	  => $cdfilial,
    		'NRCOMANDA'   => $nrcomanda,
    		'NRVENDAREST' => $nrvendarest
    	);
    	$resultPayment = $this->entityManager->getConnection()->fetchAssoc("GET_ORDER_PARAMS_DLV", $params);
    	$resultPayment['TIPORECE'] = $this->entityManager->getConnection()->fetchALL("GET_PAYMENT_DLV", $params);

    	$resultPayment['error'] = false;
    	return $resultPayment;
    }

    public function getIDORIGEMVENDADLV($NRVENDAREST) {
		$params = array(
			'NRVENDAREST' => $NRVENDAREST
		);
		return  $this->entityManager->getConnection()->fetchAssoc("GET_ORIGEM_VENDA_DLV", $params)['IDORGCMDVENDA'];
	}

	public function updateTaxaServico($CDFILIAL, $CDLOJA, $NRVENDAREST, $NRCOMANDA) {
	    $params = array(
	        'CDFILIAL' => $CDFILIAL,
	        'NRVENDAREST' => $NRVENDAREST,
	        'NRCOMANDA' => $NRCOMANDA,
	        'CDPRODUTO' => null
	    );
	    $posicoes = $this->entityManager->getConnection()->fetchAll("SQL_POSICAO_PARCIAL", $params);

	    if ($posicoes && is_array($posicoes) && count($posicoes) > 0) {
	        $precoTxSum = 0;
	        foreach ($posicoes as $posicao) {
	            if (isset($posicao['PRECOTX'])) {
	                $precoTxSum += $posicao['PRECOTX'];
	            }
	        }

	        $params = array(
	            'PRECOTXTOTAL' => $precoTxSum,
	            'CDFILIAL' => $CDFILIAL,
	            'CDLOJA' => $CDLOJA,
	            'NRVENDAREST' => $NRVENDAREST,
	            'NRCOMANDA' => $NRCOMANDA
	        );
	        $this->entityManager->getConnection()->executeQuery("UPDATE_VRCOMISVENDE", $params);
	    }
	}

	public function validaTipoConsReceb($TIPORECE, $CDCLIENTE, $CDCONSUMIDOR) {
		if(!empty($CDCONSUMIDOR)) {
			$params = array(
				'CDCLIENTE' => $CDCLIENTE,
				'CDCONSUMIDOR' => $CDCONSUMIDOR
			);
		   	$cdsTipoConsReceb = $this->entityManager->getConnection()->fetchAll("SQL_TIPO_CONS_RECEB", $params);
			if ($cdsTipoConsReceb && is_array($cdsTipoConsReceb) && count($cdsTipoConsReceb) > 0) {
				foreach ($cdsTipoConsReceb as $stTipoConsReceb) {
					if ($stTipoConsReceb['CDTIPORECE'] == $TIPORECE) {
						return true;
					}
				}
			} else {
				return true;
			}
			return false;
		} else {
			$params = array();
			$cdsTipoConsReceb = $this->entityManager->getConnection()->fetchAll("SQL_TIPO_CONS_RECEB_GERAL", $params);
			if ($cdsTipoConsReceb && is_array($cdsTipoConsReceb) && count($cdsTipoConsReceb) > 0) {
				foreach ($cdsTipoConsReceb as $stTipoConsReceb) {
					if ($stTipoConsReceb['CDTIPORECE'] == $TIPORECE) {
						return false;
					}
				}
			}
		}
		return true;
	}

	public function chamadaAPICartaoTodo($rota, $params) {
		return $this->cartaoTodo->chamadaAPICartaoTodo($rota, $params);
	}

	public function savePayment($paymentData, $session) {
		$dateTime = new \DateTime('NOW', new \DateTimeZone('America/Bahia'));
		$this->util->newCode('MOVCAIXAMOB' . $session['CDFILIAL']);

		// Validacao dos campos NRVENDAREST, NRCOMANDA E NRMESA para o modo balcÃ£o que nÃ£o possui essas informaÃ§Ãµes.
	    $params = array(
	        'CDFILIAL' 		 => $session['CDFILIAL'],
	        'CDCAIXA' 		 => $session['CDCAIXA'],
	        'CDVENDEDOR' 	 => $session['CDVENDEDOR'],
	        'NRVENDAREST' 	 => empty($paymentData['NRVENDAREST']) ? '0' : $paymentData['NRVENDAREST'],
	        'NRCOMANDA' 	 => empty($paymentData['NRCOMANDA']) ? '0' : $paymentData['NRCOMANDA'],
	        'NRSEQVENDA' 	 => null,
	        'NRMESA' 		 => empty($paymentData['NRMESA']) ? '0' : $paymentData['NRMESA'],
	        'NRLUGARMESA' 	 => 'T',
	        'DTHRINCMOV' 	 => $dateTime,
            'VRMOV' 		 => $paymentData["VRMOVIVEND"],
            'IDTIPMOV' 		 => 'E',
            'DSBANDEIRA'	 => $paymentData['eletronicTransacion']['data']['CDBANCARTCR'],
            'NRADMCODE' 	 => $paymentData['eletronicTransacion']['data']['NRCONTROLTEF'],
            'IDADMTASK' 	 => '0',
            'NRORG' 		 => $session['NRORG'],
            'NRORGINCLUSAO'  => $session['NRORG'],
            'IDATIVO' 		 => 'S',
            'DTINCLUSAO' 	 => $dateTime,
            'CDOPERINCLUSAO' => $session['CDOPERADOR'],
            'CDTIPORECE' 	 => $paymentData['tiporece']['CDTIPORECE'],
            // Nsu retornado do host autorizador - CDNSUHOSTTEF na tabela MOVCAIXA.
            'CDNSUTEFMOB' 	 => $paymentData['eletronicTransacion']['data']['CDNSUHOSTTEF'],
            'TXPRIMVIATEF' 	 => $paymentData['eletronicTransacion']['data']['STLPRIVIA'],
            'TXSEGVIATEF' 	 => $paymentData['eletronicTransacion']['data']['STLSEGVIA'],
            'IDTPTEF' 		 => $paymentData['eletronicTransacion']['data']['IDTPTEF'],
            'CDCLIENTE' 	 => $paymentData['CDCLIENTE'],
            'CDCONSUMIDOR' 	 => $paymentData['CDCONSUMIDOR'],
            'IDSTMOV' 		 => '1',
            'NRCARTBANCO' 	 => $paymentData['eletronicTransacion']['data']['NRCARTBANCO'],
            'IDTIPORECE' 	 => $paymentData['tiporece']['IDTIPORECE'],
            'TRANSACTIONCODE'=> !empty($paymentData['eletronicTransacion']['data']['TRANSACTIONCODE']) ? $paymentData['eletronicTransacion']['data']['TRANSACTIONCODE'] : $session['CDFILIAL'] . "_" . $session['CDCAIXA'] . "_" . $paymentData['saleCode']['saleCode'],
			'TRANSACTIONID'  => !empty($paymentData['eletronicTransacion']['data']['TRANSACTIONID']) ? $paymentData['eletronicTransacion']['data']['TRANSACTIONID'] : null,
			// Nsu retornado da própria integração - CDNSUTEF na tabela MOVCAIXA.
			'CDNSUTEFINTMOB' => !empty($paymentData['eletronicTransacion']['data']['CDNSUTEF']) ? $paymentData['eletronicTransacion']['data']['CDNSUTEF'] : $paymentData['eletronicTransacion']['data']['CDNSUHOSTTEF'],
			'NRAUTORIZATEF' => isset($paymentData['eletronicTransacion']['data']['NRAUTORIZATEF']) ? $paymentData['eletronicTransacion']['data']['NRAUTORIZATEF'] : null,
			'IDADIANTAMENTO' => 'N',
			'IDSTATUSMOV' => !empty($paymentData['eletronicTransacion']['data']['IDSTATUSMOV']) ? $paymentData['eletronicTransacion']['data']['IDSTATUSMOV'] : null,
	    );

		$types = array(
			'DTHRINCMOV' => \Doctrine\DBAL\TypeS\Type::DATETIME,
			'DTINCLUSAO' => \Doctrine\DBAL\TypeS\Type::DATETIME
		);
		$retorno = Array();
		$retorno['NRSEQMOVMOB'] = Array();
		$retorno['DTHRINCMOV'] = $dateTime->format('Y-m-d H:i:s');
		$lugares = $paymentData['NRLUGARMESA'];
		$lugaresLength = !is_null($lugares)? sizeof($lugares) : 0;
		if($lugaresLength > 0 && $lugaresLength !== intval($paymentData['NRPESMESAVEN'])) {
			for($i = 0; $i < $lugaresLength; $i++) {
				$this->util->newCode('MOVCAIXAMOB' . $session['CDFILIAL']);
				$params['NRSEQMOVMOB'] = $this->util->getNewCode('MOVCAIXAMOB' . $session['CDFILIAL'], 10);
				array_push($retorno['NRSEQMOVMOB'],$params['NRSEQMOVMOB']);
				$params['NRLUGARMESA'] = str_pad($lugares[$i], 2, "0", STR_PAD_LEFT);
				$this->entityManager->getConnection()->executeQuery("SQL_INSERT_MOVCAIXAMOB", $params, $types);
			}
		} else {
			$params['NRSEQMOVMOB'] =  $this->util->getNewCode('MOVCAIXAMOB' . $session['CDFILIAL'], 10);
			array_push($retorno['NRSEQMOVMOB'],$params['NRSEQMOVMOB']);
			$this->entityManager->getConnection()->executeQuery("SQL_INSERT_MOVCAIXAMOB", $params, $types);
		}

		$this->util->LogBandeira(
			"Salvando tentativa de pagamento: CDCAIXA:".$params['CDCAIXA'].
			" DSBANDEIRA: ".$params['DSBANDEIRA'].
			" NRCOMANDA: ".$params['NRCOMANDA'].
			" VRMOV: ".$params['VRMOV'].
			" NSU: ".$params['CDNSUTEFMOB']." ".$params['CDNSUTEFINTMOB'].
			" NRSEQMOVMOB: ".preg_replace( '/[\n,A,r,y,a,  ]/', "", print_r($retorno['NRSEQMOVMOB'],true) )
		);

		return $retorno;
	}

    public function handleRemovePayment($paymentData, $session, $adiantamento){
        if (isset($paymentData['DATA'])){
            $paymentData = $paymentData['DATA'];
        }
        return $this->removePayment($paymentData, $session, $adiantamento);
    }

    private function removePayment($payment, $session, $adiantamento){
		if(isset($payment[0]['NRVENDAREST'])){
			$NRVENDAREST = $payment[0]['NRVENDAREST'];
		} else if(isset($payment['NRVENDAREST'])){
			$NRVENDAREST = $payment['NRVENDAREST'];
		}
		if(isset($payment[0]['NRCOMANDA'])){
			$NRCOMANDA = $payment[0]['NRCOMANDA'];
		} else if(isset($payment['NRCOMANDA'])){
			$NRCOMANDA = $payment['NRCOMANDA'];
		}
		$NRSEQMOVMOB = Array();
		if(isset($payment[0]['NRSEQMOVMOB'])){
			foreach ($payment as $value){
				if(isset($value['NRSEQMOVMOB'])){
					foreach ($value['NRSEQMOVMOB'] as $ids) {
						array_push($NRSEQMOVMOB,$ids);
					}
				}
			}
		} else {
			if(isset($payment['TIPORECE'])){
				if(!empty($payment['TIPORECE'])){
					foreach ($payment['TIPORECE'] as $value){
						if(isset($value['NRSEQMOVMOB'])){
							foreach ($value['NRSEQMOVMOB'] as $ids) {
								array_push($NRSEQMOVMOB,$ids);
							}
						}
					}
        		}
        	}
        }

		$this->util->LogBandeira(
			"remove pagamento: ".
			" adiantamento: ".(($adiantamento)?'S':'N').
			" CDCAIXA: ".$session['CDCAIXA'].
			" NRCOMANDA: ".(empty($NRCOMANDA) ? '0' : $NRCOMANDA).
			" CDNSUHOSTTEF: ".preg_replace( '/[\n,A,r,y,a,  ]/', "", print_r(array_column($payment, 'CDNSUHOSTTEF'),true) ).
			" NRSEQMOVMOB: ".preg_replace( '/[\n,A,r,y,a,  ]/', "", print_r($NRSEQMOVMOB,true) )
		);
        if ($adiantamento){
            $params = array(
                'CDFILIAL'       => $session['CDFILIAL'],
                'NRVENDAREST'    => empty($NRVENDAREST) ? '0' : $NRVENDAREST,
                'NRCOMANDA'      => empty($NRCOMANDA) ? '0' : $NRCOMANDA,
				'NRSEQMOVMOB'    => $NRSEQMOVMOB,
                'NRORG'          => $session['NRORG']
            );
            $types = array(
				'NRSEQMOVMOB' => \Doctrine\DBAL\Connection::PARAM_STR_ARRAY
            );
            $this->entityManager->getConnection()->executeQuery("SQL_DELETE_MOVCAIXAMOB", $params, $types);
        } else {
            $params = array(
                'CDFILIAL'       => $session['CDFILIAL'],
                'NRVENDAREST'    => empty($NRVENDAREST) ? '0' : $NRVENDAREST,
                'NRCOMANDA'      => empty($NRCOMANDA) ? '0' : $NRCOMANDA,
				'NRSEQMOVMOB'    => $NRSEQMOVMOB,
                'NRORG'          => $session['NRORG']
            );
            $types = array(
				'NRSEQMOVMOB' => \Doctrine\DBAL\Connection::PARAM_STR_ARRAY
            );
            $this->entityManager->getConnection()->executeQuery("SQL_DELETE_MOVCAIXAMOB", $params, $types);
            $params = array(
                'CDFILIAL'       => $session['CDFILIAL'],
                'NRVENDAREST'    => empty($NRVENDAREST) ? '0' : $NRVENDAREST,
                'NRCOMANDA'      => empty($NRCOMANDA) ? '0' : $NRCOMANDA,
				'NRSEQMOVMOB'    => $NRSEQMOVMOB,
                'NRORG'          => $session['NRORG']
            );
            $types = array(
				'NRSEQMOVMOB' => \Doctrine\DBAL\Connection::PARAM_STR_ARRAY
            );
            $this->entityManager->getConnection()->executeQuery("SQL_DELETE_MOVCAIXAMOB", $params, $types);
        }
        return;
    }

	public function getPayments($paymentData, $session){
		if(!isset($paymentData['posicoes'])){
			$paymentData['posicoes'] = Array();
		}
		if(empty($paymentData['posicoes'])){
			$paymentData['posicoes'] = Array('T');
		} else {
			foreach ($paymentData['posicoes'] as &$value) {
				if($value!="T"){
					if (is_array($value)) $value = $value['NRLUGARMESA'];
					$value = str_pad($value, 2, "0", STR_PAD_LEFT);
				}				
			}
			if(intval($paymentData['NRPOSICAOMESA'])>0){
				if(intval($paymentData['NRPOSICAOMESA'])>=count($paymentData['posicoes'])){
					array_push($paymentData['posicoes'],'T');
				}
			}
		}
		$params = array(
	    	'CDFILIAL' 		 => $session['CDFILIAL'],
	        'NRVENDAREST' 	 => $paymentData['NRVENDAREST'],
	        'NRCOMANDA' 	 => $paymentData['NRCOMANDA'],
            'NRORG' 		 => $session['NRORG'],
			'NRLUGARMESA'    => $paymentData['posicoes']
	    );
		$types = array(
			'NRLUGARMESA' => \Doctrine\DBAL\Connection::PARAM_STR_ARRAY
	    );
		$arrMOVCAIXAMOB = $this->entityManager->getConnection()->fetchAll("SQL_BUSCA_MOVCAIXAMOB_POSICAO", $params,$types);
		$arrMOVCAIXAMOBtemp = $arrMOVCAIXAMOB;
		$anterior = null;
		$stRemover = "";
		$PosicoesemRecebimento = Array();
		foreach ($arrMOVCAIXAMOB as $key => &$MOVCAIXAMOB) {
			if(!in_array($MOVCAIXAMOB['NRLUGARMESA'],$PosicoesemRecebimento)){
				array_push($PosicoesemRecebimento,$MOVCAIXAMOB['NRLUGARMESA']);
			}
			$MOVCAIXAMOB['NRSEQMOVMOB'] = Array($MOVCAIXAMOB['NRSEQMOVMOB']);
			foreach ($arrMOVCAIXAMOBtemp as $keytemp => $MOVCAIXAMOBtemp) {
				if(
					$MOVCAIXAMOBtemp['VRMOV']==$MOVCAIXAMOB['VRMOV'] &&
					$MOVCAIXAMOBtemp['DTHRINCMOV']==$MOVCAIXAMOB['DTHRINCMOV'] &&
					$MOVCAIXAMOBtemp['CDTIPORECE']==$MOVCAIXAMOB['CDTIPORECE'] &&
					$MOVCAIXAMOBtemp['CDNSUTEFMOB']==$MOVCAIXAMOB['CDNSUTEFMOB'] &&
					$MOVCAIXAMOBtemp['NRLUGARMESA']!=$MOVCAIXAMOB['NRLUGARMESA']
				){
					if(!strrpos($stRemover, $MOVCAIXAMOB['NRSEQMOVMOB'][0])){
						$stRemover = $stRemover."_".$MOVCAIXAMOBtemp['NRSEQMOVMOB'];
					array_push($MOVCAIXAMOB['NRSEQMOVMOB'],$MOVCAIXAMOBtemp['NRSEQMOVMOB']);
					} else {
						unset($arrMOVCAIXAMOB[$key]);
					}
				}
			}
		}
		sort($PosicoesemRecebimento);
		foreach ($arrMOVCAIXAMOB as $key => &$MOVCAIXAMOB) {
			$MOVCAIXAMOB['PosicoesEmRecebimento'] = $PosicoesemRecebimento;
		}
		$arrMOVCAIXAMOB = array_values( $arrMOVCAIXAMOB );
		return $arrMOVCAIXAMOB;
	}

    public function validateVoucher($CDPRODUTO, $NRVENDAREST, $NRCOMANDA, $CDCUPOMDESCFOS){
        $session = $this->util->getSessionVars(null);

        $CDCUPOMDESCFOS = trim($CDCUPOMDESCFOS);

        if (empty($CDCUPOMDESCFOS)) throw new \Exception("Código do voucher vazio - favor informar o código.");

        $params = array(
            'CDPRODUTO'      => $CDPRODUTO,
            'CDCUPOMDESCFOS' => $CDCUPOMDESCFOS,
        );
        $voucher = $this->entityManager->getConnection()->fetchAssoc("SQL_BUSCA_VOUCHER", $params);
        if (empty($voucher)){
            throw new \Exception("O código informado não existe, ou não pode ser utilizado neste produto.");
        }

        $params = array(
            'CDCUPOMDESCFOS' => $CDCUPOMDESCFOS
        );
        $voucherData = $this->entityManager->getConnection()->fetchAssoc("SQL_VALIDATE_VOUCHER", $params);
        if (empty($voucherData)){
            throw new \Exception("O cupom informado encontra-se fora do prazo de validade.");
        }

        $validation = $this->entityManager->getConnection()->fetchAll("SQL_FILIAL_CUPOM", $params);
        if (!empty($validation)){
            $match = false;
            foreach ($validation as $CDFILIAL){
                if ($CDFILIAL['CDFILIAL'] == $session['CDFILIAL']){
                    $match = true;
                    break;
                }
            }
            if (!$match) throw new \Exception("O cupom informado não pode ser utilizado nesta filial.");
        }

        if ($voucherData['IDUSOUNICO'] === 'S'){
            $usageCheck = $this->entityManager->getConnection()->fetchAll("SQL_VOUCHER_USAGE", $params);

            $params = array(
                'CDFILIAL' => $session['CDFILIAL'],
                'NRVENDAREST' => $NRVENDAREST,
                'NRCOMANDA' => $NRCOMANDA,
                'CDCUPOMDESCFOS' => $CDCUPOMDESCFOS
            );
            $voucheredProducts = $this->entityManager->getConnection()->fetchAssoc("SQL_GET_VOUCHERED_PRODUCTS", $params);

            if (!empty($usageCheck) || !empty($voucheredProducts)){
                throw new \Exception("O cupom informado já foi utilizado.");
            }
        }

        return $voucherData;
    }

    public function getTiporeceH() {
		return $this->entityManager->getConnection()->fetchAll("GET_TIPORECE_H");
	}

	public function searchAndAddAdvancedPayments($chave, $CDFILIAL, $CDCAIXA, &$TIPORECE, $NRVENDAREST, $NRCOMANDA) {
		$advancedTIPORECE = self::searchAdvancedPayments($chave, $CDFILIAL, $CDCAIXA, $NRVENDAREST, $NRCOMANDA);

		if(!empty($TIPORECE)) {
			foreach($advancedTIPORECE as $actualAdvPayment){
				$actualAdvPayment['VRMOVIVEND'] = $actualAdvPayment['VRMOV'];
				array_push($TIPORECE, $actualAdvPayment);
			}
		}
	}

	public function getAdvanceInfoCOMANDAVEN($CDFILIAL, $NRVENDAREST, $NRCOMANDA) {
		$params = array(
			'CDFILIAL' => $CDFILIAL,
			'NRVENDAREST' => $NRVENDAREST,
			'NRCOMANDA' => $NRCOMANDA
		);
		$infoComanda = $this->entityManager->getConnection()->fetchAll("GET_ADVANCE_COMANDAVEN", $params);

		if(!empty($infoComanda)) {
            $adiantamentos = $this->entityManager->getConnection()->fetchAll("GET_ADVANCED_PAYMENTS", $params);
			foreach($infoComanda as &$cmd){
				$cmd['IDADIANTAMENTO'] = empty($adiantamentos)?'N':'S';
			}
			return $infoComanda;
		}
		return array();
	}

	public function updateAdiantamentoCOMANDAVEN($chave, $CDFILIAL, $NRCOMANDA, $NRVENDAREST) {
		$params = array(
    		'CDFILIAL' => $CDFILIAL,
    		'NRCOMANDA' => $NRCOMANDA,
    		'NRVENDAREST' => $NRVENDAREST
    	);
		$this->entityManager->getConnection()->executeQuery("UPDATE_ADIANTAMENTO_COMANDAVEN", $params);
	}

	public function searchAdvancedPayments($chave, $CDFILIAL, $CDCAIXA, $NRVENDAREST, $NRCOMANDA) {
		$params = array(
			'CDFILIAL' => $CDFILIAL,
			'CDCAIXA' => $CDCAIXA,
			'NRVENDAREST' => $NRVENDAREST,
			'NRCOMANDA' => $NRCOMANDA
		);
		return $this->entityManager->getConnection()->fetchAll("GET_ADVANCED_PAYMENTS", $params);
	}

	public function callCrmBunus($URL, $headers, $body){

        $curl = curl_init();

        curl_setopt($curl, CURLOPT_URL, $URL);

        curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);

        curl_setopt($curl, CURLOPT_POST, true);
        curl_setopt($curl, CURLOPT_POSTFIELDS, $body);

        curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, 0);
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, 0);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_TIMEOUT, 20);
        curl_setopt($curl, CURLOPT_CONNECTTIMEOUT, 10);

        /*if (!empty($this->instanceManager->getParameter('PROXY_IP'))){
            curl_setopt($curl, CURLOPT_PROXY, $this->instanceManager->getParameter('PROXY_IP').":".$this->instanceManager->getParameter('PROXY_PORT'));
            if (!empty($this->instanceManager->getParameter('PROXY_USER'))){
                curl_setopt($curl, CURLOPT_PROXYUSERPWD, $this->instanceManager->getParameter('PROXY_USER').":".$this->instanceManager->getParameter('PROXY_PASSWORD'));
            }
        }*/

        $curl_response = curl_exec($curl);
        $err    = curl_errno($curl);
        $errmsg = curl_error($curl);
        curl_close($curl);

        // var_dump($curl_response);
        // var_dump($err);
        // var_dump($errmsg);die;
        $curl_response = json_decode($curl_response, true);

        if (!empty($err)){
            throw new \Exception("<br>Erro ao conectar com a api CRM&BONUS.<br><br>". $errmsg);
            $this->util->LogCRMBonus("Erro ao conectar com a api -> ERRO: {$errmsg}");
        } else if (empty($curl_response)){
            throw new \Exception("<br>Não houve retorno da api CRM&BONUS.");
        } else if($curl_response["status"] != true){
            throw new \Exception("<br>Erro na requisição: <br>" . $curl_response["message"]);
            $this->util->LogCRMBonus("Erro na requisição -> ERRO: {$curl_response["message"]}");
        }
        return $curl_response;
    }

    public function getCDTIPORECE($CDFILIAL, $CDCAIXA, $NRVENDAREST, $NRCOMANDA, $arrNRSEQMOVMOB){
		foreach ($arrNRSEQMOVMOB as $NRSEQMOVMOB) {
			$params = array(
				'CDFILIAL'     => $CDFILIAL,
				'NRVENDAREST'  => empty($NRVENDAREST) ? '0' : $NRVENDAREST,
				'NRCOMANDA'    => empty($NRCOMANDA) ? '0' : $NRCOMANDA,
				'NRSEQMOVMOB'  => $NRSEQMOVMOB
			);
			$arrCDTIPORECE = $this->entityManager->getConnection()->fetchAll("GET_MOVCAIXAMOB_NRSEQMOVMOB", $params);
			if(!empty($arrCDTIPORECE)){
				if(!empty($arrCDTIPORECE[0]['CDTIPORECE'])){
					$CDTIPORECE = $arrCDTIPORECE[0]['CDTIPORECE'];
					return $CDTIPORECE;
				}
			}
		}
		return "";
	}

    public function updatePayment($CDNSUHOSTTEF, $CDFILIAL, $CDCAIXA, $NRVENDAREST, $NRCOMANDA, $arrNRSEQMOVMOB, $DSBANDEIRA, $CDTIPORECE){
        foreach ($arrNRSEQMOVMOB as $NRSEQMOVMOB) {
			if(empty($CDTIPORECE)){
				$CDTIPORECE = self::getCDTIPORECE($CDFILIAL, $CDCAIXA, $NRVENDAREST, $NRCOMANDA, $arrNRSEQMOVMOB);
				if(empty($CDTIPORECE)){
					throw new \Exception("Não foi possível atualizar o pagamento, código identificador não encotrado.");
				}
			}
			$params = array(
				'CDNSUHOSTTEF' => $CDNSUHOSTTEF,
				'IDSTATUSMOV'  => null,
				'CDFILIAL'     => $CDFILIAL,
				'NRVENDAREST'  => empty($NRVENDAREST) ? '0' : $NRVENDAREST,
				'NRCOMANDA'    => empty($NRCOMANDA) ? '0' : $NRCOMANDA,
				'NRSEQMOVMOB'  => $NRSEQMOVMOB,
				'DSBANDEIRA'   => $DSBANDEIRA,
				'CDTIPORECE'   => $CDTIPORECE
			);
			$this->entityManager->getConnection()->executeQuery("UPDATE_IDSTATUSMOV_MOVCAIXAMOB", $params);
			$this->util->LogBandeira(
				"Atualizando pagamento CAIXA:".$CDCAIXA.", ".
				" DSBANDEIRA: ".$DSBANDEIRA.", ".
				" CDNSUHOSTTEF: ".$params['CDNSUHOSTTEF'].", ".
				" NRCOMANDA: ".$params['NRCOMANDA'].", ".
				" NRSEQMOVMOB: ".$params['NRSEQMOVMOB'].
				" CDTIPORECE: ".$params['CDTIPORECE']
			);
		}
    }

    public function undoPayment($CDFILIAL, $NRVENDAREST, $NRCOMANDA, $arrNRSEQMOVMOB){
		foreach ($arrNRSEQMOVMOB as $NRSEQMOVMOB) {
			$params = array(
				'CDFILIAL'     => $CDFILIAL,
				'NRVENDAREST'  => empty($NRVENDAREST) ? '0' : $NRVENDAREST,
				'NRCOMANDA'    => empty($NRCOMANDA) ? '0' : $NRCOMANDA,
				'NRSEQMOVMOB'  => $NRSEQMOVMOB
			);
			$this->entityManager->getConnection()->executeQuery("DELETE_MOVCAIXAMOB_NRSEQMOVMOB", $params);
			$this->util->LogBandeira(
				"remove pagamento: ".
				" NRCOMANDA: ".$params['NRCOMANDA'].
				" NRSEQMOVMOB: ".$params['NRSEQMOVMOB']
			);
		}
    }

	public function temCampanhaFidelidadeOnline($CDFILIAL){
		return $this->fidelidadeOnline->temCampanhaFidelidadeOnline($CDFILIAL);
    }

	public function checkSaldoFidelidadeOnline($CDCLIENTE, $CDCONSUMIDOR){
		$session  = $this->util->getSessionVars(null);

		return $this->fidelidadeOnline->checkSaldoFidelidadeOnline($session['CDFILIAL'], 
			$session['CDURLFIDONLINE'], $CDCLIENTE, $CDCONSUMIDOR);
    }

	public function curlGetBalanceFidelidadeOnline($CDCLIENTE, $CDCONSUMIDOR, $CDCAMPANHA) {
		$session  = $this->util->getSessionVars(null);

		return $this->fidelidadeOnline->curlGetBalanceFidelidadeOnline($session['CDURLFIDONLINE'], $CDCLIENTE, 
			$CDCONSUMIDOR, $CDCAMPANHA);
	}

	public function curlRedeemBalanceFidelidadeOnline($NRSEQVENDA, $CDCLIENTE, $CDCONSUMIDOR, $DTABERCAIX, 
		$CDCAMPANHA, $CREDITOUSADO) {
		$session  = $this->util->getSessionVars(null);

		return $this->fidelidadeOnline->curlRedeemBalance($session['CDURLFIDONLINE'], $session['CDFILIAL'], 
			$session['CDCAIXA'], $NRSEQVENDA, $CDCLIENTE, $CDCONSUMIDOR, ltrim($CDCONSUMIDOR, '0'), $DTABERCAIX, 
			$CDCAMPANHA, $CREDITOUSADO);
	}

	public function curlCancelBalanceFidelidadeOnline($NRSEQVENDA, $CDCLIENTE, $CDCONSUMIDOR) {
		$session  = $this->util->getSessionVars(null);

		return $this->fidelidadeOnline->curlCancelBalance($session['CDURLFIDONLINE'], $session['CDFILIAL'], 
			$session['CDCAIXA'], $NRSEQVENDA, $CDCLIENTE, $CDCONSUMIDOR);
	}

	public function curlGetConsumerFidelidadeOnline($CDCONSUMIDOR) {
		$session  = $this->util->getSessionVars(null);
		
		return $this->fidelidadeOnline->curlGetConsumer($session['CDURLFIDONLINE'], ltrim($CDCONSUMIDOR, '0'));
	}

	public function curlGetSaleResumeFidelidadeOnline($NRSEQVENDA, $CDCLIENTE, $CDCONSUMIDOR, $DTABERCAIX) {
		$session  = $this->util->getSessionVars(null);

		return $this->fidelidadeOnline->curlGetSaleResumeFidelidadeOnline($session['CDURLFIDONLINE'], 
			$session['CDFILIAL'], $session['CDCAIXA'], $NRSEQVENDA, $CDCLIENTE, $CDCONSUMIDOR, $DTABERCAIX);
	}
}